aboutsummaryrefslogtreecommitdiffstats
path: root/src/scratchpad/testcases/org/apache/poi/hsmf
diff options
context:
space:
mode:
authorNick Burch <nick@apache.org>2013-06-26 18:46:37 +0000
committerNick Burch <nick@apache.org>2013-06-26 18:46:37 +0000
commit2d0241181a52b216852bb5c248a46ef2ce2577a1 (patch)
tree1c6ab3edb7521355d9649a9299e47bff3c2990ae /src/scratchpad/testcases/org/apache/poi/hsmf
parent4110133f8e013e790667faa1891f19b518dd07a5 (diff)
downloadpoi-2d0241181a52b216852bb5c248a46ef2ce2577a1.tar.gz
poi-2d0241181a52b216852bb5c248a46ef2ce2577a1.zip
Have MAPIMessage try the codepage properties to get the ascii encoding, before falling back to the existing logic around content type parsing
git-svn-id: https://svn.apache.org/repos/asf/poi/trunk@1497038 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'src/scratchpad/testcases/org/apache/poi/hsmf')
-rw-r--r--src/scratchpad/testcases/org/apache/poi/hsmf/TestBasics.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/scratchpad/testcases/org/apache/poi/hsmf/TestBasics.java b/src/scratchpad/testcases/org/apache/poi/hsmf/TestBasics.java
index c250c0e412..a6e468767e 100644
--- a/src/scratchpad/testcases/org/apache/poi/hsmf/TestBasics.java
+++ b/src/scratchpad/testcases/org/apache/poi/hsmf/TestBasics.java
@@ -229,8 +229,8 @@ public final class TestBasics extends TestCase {
// Defaults to CP1251
assertEquals("CP1252", chinese.getRecipientDetailsChunks()[0].recipientDisplayNameChunk.get7BitEncoding());
// But after guessing goes to the correct one, Big 5
chinese.guess7BitEncoding();
- assertEquals("big5", chinese.getRecipientDetailsChunks()[0].recipientDisplayNameChunk.get7BitEncoding());
+ assertEquals("cp950", chinese.getRecipientDetailsChunks()[0].recipientDisplayNameChunk.get7BitEncoding());
}
}
@@ -229,8 +229,8 @@ public final class TestBasics extends TestCase {
// Defaults to CP1251
assertEquals("CP1252", chinese.getRecipientDetailsChunks()[0].recipientDisplayNameChunk.get7BitEncoding());
- // But after guessing goes to the correct one, Big 5
+ // But after guessing goes to the correct one, cp950 (Windows Traditional Chinese)
chinese.guess7BitEncoding();